@@ -27,13 +27,14 @@ def timestamp_to_int(timestamp: str) -> int:
     return int(dt.timestamp())
 
 
-def create_output_filename(input_uri: str, create_time: int, output_format: str) -> str:
+def create_output_filename(input_filename: str, create_time: int, output_format: str = None) -> str:
     """Creates output filename from input_uri, create_time and output_format"""
-
-    filename = os.path.basename(input_uri)
-    output_filename = f"{os.path.splitext(filename)[0]}-{datetime.fromtimestamp(create_time/1e3).strftime('%Y%m%d_%I%M%S_%p')}.{output_format}"
-
-    return output_filename
+    basefilename = os.path.splitext(input_filename)[0]
+    timestamp = datetime.fromtimestamp(create_time / 1e3).strftime("%Y-%m-%d-%I-%M%-S-%p")
+    if output_format:
+        return f"{basefilename}-{timestamp}.{output_format}"
+    else:
+        return f"{basefilename}-{timestamp}"
 
 
 def find_cell_index_with_tag(nb: NotebookNode, tag: str) -> int:
