@@ -1,4 +1,4 @@
-import React, { useCallback, useEffect, useState } from 'react';
+import React, { useCallback, useEffect, useState, useMemo } from 'react';
 
 import { useTheme } from '@mui/material/styles';
 import Table from '@mui/material/Table';
@@ -134,16 +134,14 @@ export function AdvancedTable<
     setTotalCount(payload.total_count);
   };
 
-  if (rows && !rows.length) {
-    return (
-      <p className={'jp-notebook-job-list-empty'}>{props.emptyRowMessage}</p>
-    );
-  }
-
-  const renderedRows: JSX.Element[] = (rows || [])
-    .slice(page * pageSize, (page + 1) * pageSize)
-    .filter(row => (props.rowFilter ? props.rowFilter(row) : true))
-    .map(row => props.renderRow(row));
+  const renderedRows: JSX.Element[] = useMemo(
+    () =>
+      (rows || [])
+        .slice(page * pageSize, (page + 1) * pageSize)
+        .filter(row => (props.rowFilter ? props.rowFilter(row) : true))
+        .map(row => props.renderRow(row)),
+    [rows, props.rowFilter, props.renderRow]
+  );
 
   const handlePageChange = async (e: unknown, newPage: number) => {
     // if newPage <= maxPage, no need to fetch more rows
@@ -174,9 +172,11 @@ export function AdvancedTable<
           // in this case.
           return trans.__('%1–%2 of %3', from, loadedRows, loadedRows);
         } else {
-          return (
-            trans.__('%1–%2 of %3', from, to,
-              loadedRows + (nextToken === undefined ? '' : '+'))
+          return trans.__(
+            '%1–%2 of %3',
+            from,
+            to,
+            loadedRows + (nextToken === undefined ? '' : '+')
           );
         }
       } else {
@@ -186,6 +186,12 @@ export function AdvancedTable<
     [rows, onLastPage, trans]
   );
 
+  if (rows && !rows.length) {
+    return (
+      <p className={'jp-notebook-job-list-empty'}>{props.emptyRowMessage}</p>
+    );
+  }
+
   return (
     <div
       style={height === 'auto' ? { flex: 1, height: 0 } : { maxHeight: height }}
