@@ -1,7 +1,10 @@
 import { useContext } from 'react';
+
+import { TranslationBundle } from '@jupyterlab/translation';
+
 import TranslatorContext from './context';
 
-export const useTranslator = (bundleId: string) => {
+export function useTranslator(bundleId: string): TranslationBundle {
   const translator = useContext(TranslatorContext);
   return translator.load(bundleId);
-};
+}
